@@ -36,6 +36,8 @@
 #include <wx/accel.h>
 #include <wx/filesys.h>
 #include <wx/mimetype.h>
+#include <wx/imaglist.h>
+#include <wx/fs_mem.h>
 
 
 #define OPEN_HELP _("Open a CHM book.")
@@ -55,12 +57,15 @@
 namespace {
 
 const wxChar *greeting = wxT(
-	"<html><body>Hello, and welcome to <B>xCHM</B>, the UNIX CHM viewer."
+	"<html><body><table border=0><tr><td align=\"left\">"
+	"<img src=\"memory:logo.xpm\"></td><td align=\"left\">"
+	"Hello, and welcome to <B>xCHM</B>, the UNIX CHM viewer."
 	"<br><br><B>xCHM</B> has been written by Razvan Cojocaru "
 	"(razvanco@gmx.net). It is licensed under the <TT>GPL</TT>.<br>"
 	"<B>xCHM</B> is based on Jed Wing's <a href=\"http://66.93.236.84/"
 	"~jedwin/projects/chmlib/\">CHMLIB</a> and <a href=\"http://www."
-	"wxwidgets.org\">wxWidgets</a>.<br><br>If you'd like to know more"
+	"wxwidgets.org\">wxWidgets</a>.</td></tr></table>"
+	"<br>If you'd like to know more"
 	" about CHM, you could check out <a href=\"http://www.speakeasy."
 	"org/~russotto/chm/\">Matthew Russoto's CHM page</a> or <a"
 	" href=\"http://www.nongnu.org/chmspec/latest/\">Pabs' CHM"
@@ -100,6 +105,7 @@ const wxChar *about_txt = wxT(
 	"This program is (proudly) under the GPL.");
 
 #include <xchm-32.xpm>
+#include <logo.xpm>
 
 } // namespace
 
@@ -136,13 +142,21 @@ CHMFrame::CHMFrame(const wxString& title, const wxString& booksDir,
 	SetIcon(wxIcon(xchm_32_xpm));
 	SetMenuBar(CreateMenu());
 
-	_tb = CreateToolBar(wxTB_FLAT | wxTB_DOCKABLE
-			    | wxTB_HORIZONTAL | wxTB_TEXT);
+	_tb = CreateToolBar(wxTB_HORIZONTAL | wxTB_TEXT
+#if defined __WXMSW__ || defined __WXGTK__			
+			   | wxTB_FLAT | wxTB_DOCKABLE
+#endif
+			   );
 	InitToolBar(_tb);
 
 	CreateStatusBar();
 	SetStatusText(_("Ready."));
 
+	wxMemoryFSHandler::AddFile(wxT("logo.xpm"), wxBITMAP(logo), 
+				   wxBITMAP_TYPE_XPM);
+	wxMemoryFSHandler::AddFile(wxT("about.html"), greeting);
+	wxMemoryFSHandler::AddFile(wxT("error.html"), error_page);
+
 	_ep = new wxHtmlEasyPrinting(wxT("Printing"), this);
 
 	_sw = new wxSplitterWindow(this);
@@ -158,7 +172,7 @@ CHMFrame::CHMFrame(const wxString& title, const wxString& booksDir,
 	_html->SetRelatedStatusBar(0);
 
 	_html->SetFonts(_normalFont, _fixedFont, sizes);	
-	_html->SetPage(greeting);
+	_html->LoadPage(wxT("memory:about.html"));
 
 	_csp = new CHMSearchPanel(_nb, _tcl, _html);
 	_font = _tcl->GetFont();
@@ -224,7 +238,12 @@ void CHMFrame::OnChangeFonts(wxCommandEvent& WXUNUSED(event))
 		wxFontEnumerator enu;
 		enu.EnumerateFacenames();
 		_normalFonts = new wxArrayString;
+
+#if wxMAJOR_VERSION == 2 && wxMINOR_VERSION > 7
+		*_normalFonts = enu.GetFacenames();
+#else
 		*_normalFonts = *enu.GetFacenames();
+#endif
 		_normalFonts->Sort();
 	}
 
@@ -232,7 +251,12 @@ void CHMFrame::OnChangeFonts(wxCommandEvent& WXUNUSED(event))
 		wxFontEnumerator enu;
 		enu.EnumerateFacenames(wxFONTENCODING_SYSTEM, TRUE);
 		_fixedFonts = new wxArrayString;
+
+#if wxMAJOR_VERSION == 2 && wxMINOR_VERSION > 7
+		*_fixedFonts = enu.GetFacenames();
+#else
 		*_fixedFonts = *enu.GetFacenames();
+#endif
 		_fixedFonts->Sort();
 	}
 
@@ -256,7 +280,7 @@ void CHMFrame::OnChangeFonts(wxCommandEvent& WXUNUSED(event))
 		wxString page = _html->GetOpenedPage();
 
 		if(page.IsEmpty())
-			_html->SetPage(greeting); 
+			_html->LoadPage(wxT("memory:about.html"));
 	}
 }
 
@@ -286,8 +310,6 @@ void CHMFrame::OnHistoryBack(wxCommandEvent& WXUNUSED(event))
 	else {
 		if(CHMInputStream::GetCache())
 			return;
-		
-		_html->SetPage(greeting);
 	}
 }
 
@@ -483,32 +505,63 @@ void CHMFrame::OnCloseWindow(wxCloseEvent& WXUNUSED(event))
 }
 
 
+void CHMFrame::OnChar(wxKeyEvent& event)
+{
+	if(event.GetKeyCode() == WXK_F9) {
+		wxCommandEvent dummy;
+		OnShowContents(dummy);
+	}
+
+	event.Skip();
+}
+
+
 bool CHMFrame::LoadCHM(const wxString& archive)
 {
 	wxBusyCursor bc;
+	wxLogNull wln;
 	bool rtn;
 	SaveBookmarks();
 	_nb->SetSelection(0);
 
-	wxFileSystem wfs;
-	wxFSFile *f = wfs.OpenFile(wxString(wxT("file:")) + archive +
-		      wxT("#xchm:/"));
-	delete f;
-	
-        CHMFile *chmf = CHMInputStream::GetCache();
+	if(!archive.StartsWith(wxT("file:")) || 
+	   !archive.Contains(wxT("#xchm:"))) {
 
-	if(!chmf)
-		return false;
+		wxFileSystem wfs;
+		wxFSFile *f = wfs.OpenFile(wxString(wxT("file:")) + archive +
+			      wxT("#xchm:/"));
+		delete f;
 	
-	rtn = _html->LoadPage(wxString(wxT("file:"))
-					+ chmf->ArchiveName()
-			                + wxT("#xchm:") 
-					+ chmf->HomePage());
-	UpdateCHMInfo();
-	LoadBookmarks();
+	        CHMFile *chmf = CHMInputStream::GetCache();
 
-	if(!rtn)
-		_html->SetPage(error_page);
+		if(!chmf)
+			return false;
+	
+		rtn = _html->LoadPage(wxString(wxT("file:"))
+						+ chmf->ArchiveName()
+				                + wxT("#xchm:") 
+						+ chmf->HomePage());
+	} else {
+		rtn = _html->LoadPage(archive);
+	}
+
+	if(!rtn) { // Error, could not load CHM file
+		if(_tcl->GetCount())
+			_tcl->DeleteAllItems();
+		if(_sw->IsSplit()) {
+			_sw->Unsplit(_nb);
+			_nb->Show(FALSE);
+		}
+		_menuFile->Check(ID_Contents, FALSE);
+		_tb->ToggleTool(ID_Contents, FALSE);
+		_cip->Reset();
+		_csp->Reset();
+		_html->LoadPage(wxT("memory:error.html"));
+
+	} else {
+		UpdateCHMInfo();
+		LoadBookmarks();
+	}
 
 	return rtn;
 }
@@ -962,6 +1015,7 @@ BEGIN_EVENT_TABLE(CHMFrame, wxFrame)
 	EVT_TREE_SEL_CHANGED(ID_TreeCtrl, CHMFrame::OnSelectionChanged)
 	EVT_COMBOBOX(ID_Bookmarks, CHMFrame::OnBookmarkSel)
 	EVT_CLOSE(CHMFrame::OnCloseWindow)
+	EVT_CHAR(CHMFrame::OnChar)
 END_EVENT_TABLE()
 
 
