@@ -23,6 +23,7 @@
 #include <chminputstream.h>
 
 
+
 // only needs to be here because I killed the constructors
 // by providing a private copy constructor
 CHMFSHandler::CHMFSHandler()
@@ -45,11 +46,12 @@ bool CHMFSHandler::CanOpen(const wxString& location)
 }
 
 
-wxFSFile* CHMFSHandler::OpenFile(wxFileSystem& WXUNUSED(fs), 
+wxFSFile* CHMFSHandler::OpenFile(wxFileSystem& fs, 
 				 const wxString& location)
 {
 	wxString right = GetRightLocation(location);
 	wxString left = GetLeftLocation(location);
+	wxString cwd = GetRightLocation(fs.GetPath());
 	CHMInputStream *s = NULL;
 
 	if(!location.Left(6).CmpNoCase(wxT("MS-ITS"))) {
@@ -58,7 +60,7 @@ wxFSFile* CHMFSHandler::OpenFile(wxFileSystem& WXUNUSED(fs),
 
 	} else if (GetProtocol(left) != wxT("file"))
 		return NULL;
-	
+
 	// HTML code for space is %20
 	right.Replace(wxT("%20"), wxT(" "), TRUE);
 	right.Replace(wxT("%5F"), wxT("_"), TRUE);
@@ -68,6 +70,16 @@ wxFSFile* CHMFSHandler::OpenFile(wxFileSystem& WXUNUSED(fs),
             
 	wxFileName filename = wxFileSystem::URLToFileName(left);
 	filename.Normalize();
+
+	size_t len = cwd.Length();
+	if(right.Length() > len && right.StartsWith(cwd)
+			&& right[len] == wxT('/'))
+		right = right.Mid(len);
+
+        wxFileName fwfn(right, wxPATH_UNIX);
+        fwfn.Normalize(wxPATH_NORM_DOTS, cwd);
+	right = fwfn.GetFullPath(wxPATH_UNIX);
+
 	s = new CHMInputStream(left.IsEmpty() ? 
 			       left : filename.GetFullPath(), right);
 
