@@ -33,11 +33,10 @@
 
 
 
-
 CHMHtmlWindow::CHMHtmlWindow(wxWindow *parent, wxTreeCtrl *tc, CHMFrame *frame)
 	: wxHtmlWindow(parent, -1, wxDefaultPosition, wxSize(200,200)),
 	  _tcl(tc), _syncTree(true), _found(false), _menu(NULL), 
-	  _absolute(false), _frame(frame), _fdlg(NULL)
+	  _frame(frame), _fdlg(NULL)
 {
 	_menu = new wxMenu;
 	_menu->Append(ID_PopupForward, _("For&ward"));
@@ -63,18 +62,9 @@ bool CHMHtmlWindow::LoadPage(const wxString& location)
 	wxLogNull log;
 	wxString tmp = location;
 
-	// Path is already absolute.
-	if(_absolute) {
-		FixPath(tmp, wxT("/"));
-		_absolute = false;
-	} else
-		FixPath(tmp, _prefix);
-
 	if(!tmp.Left(19).CmpNoCase(wxT("javascript:fullsize"))) 
 		tmp = tmp.AfterFirst(wxT('\'')).BeforeLast(wxT('\''));
 
-	_prefix = GetPrefix(tmp);
-
 	if(_syncTree && 
 	   // We should be looking for a valid page, not / (home).
 	   !location.AfterLast(wxT('/')).IsEmpty() && 
@@ -112,7 +102,7 @@ void CHMHtmlWindow::Sync(wxTreeItemId root, const wxString& page)
 
 	if(data)
 		url = (data->_url).BeforeFirst(wxT('#'));
-
+	
 	if(data && (!url.CmpNoCase(page) || 
 		    !url.CmpNoCase(GetPrefix(GetOpenedPage()) + wxT("/") 
 				   + page))) {
@@ -139,92 +129,6 @@ wxString CHMHtmlWindow::GetPrefix(const wxString& location) const
 }
 
 
-bool CHMHtmlWindow::FixPath(wxString &location,
-			    const wxString& prefix) const
-{
-	wxLogNull wln;
-
-        if(!location.Left(5).CmpNoCase(wxT("http:")) ||
-           !location.Left(6).CmpNoCase(wxT("https:")) ||
-           !location.Left(4).CmpNoCase(wxT("ftp:")) || 
-           !location.Left(7).CmpNoCase(wxT("mailto:")) ||
-           !location.Left(7).CmpNoCase(wxT("ms-its:")) ||
-           !location.Left(10).CmpNoCase(wxT("javascript")) ||
-           location.StartsWith(wxT("#")))
-                return false;
-
-	CHMFile *chmf = CHMInputStream::GetCache();
-
-	if(!chmf)
-		return false;
-
-	bool full = location.StartsWith(wxT("file:"));
-	bool repairWX = false;
-	size_t len = 0;
-
-	if(full) {
-		wxString basepath = GetParser()->GetFS()->GetPath();
-		len = basepath.Length();
-		
-		repairWX = location.StartsWith(basepath)
-			&& len < location.Length()
-			&& location[len] == wxT('/');
-	}
-
-	if(!repairWX && full && !location.Contains(wxT("./")))
-		return false;
-	
-	wxString arch;
-	wxString file;
-
-	if(full)
-		arch = location.BeforeFirst(wxT('#')).Mid(5);
-	else
-		arch = chmf->ArchiveName();			
-
-	wxFileName awfn(arch);
-	awfn.Normalize();
-
-	if(full) {
-		if(!repairWX)
-			file = location.AfterFirst(wxT('#')).
-				AfterFirst(wxT(':'));
-		else 
-			file = location.Mid(len);
-	} else 
-		file = location;
-
-	if(!file.StartsWith(wxT("/"))) 
-		file = wxString(wxT("/")) + prefix + wxT("/") + file;
-
-	wxFileName fwfn(file, wxPATH_UNIX);
-	fwfn.Normalize(wxPATH_NORM_DOTS);
-
-	location = wxString(wxT("file:")) + awfn.GetFullPath() +
-		wxString(wxT("#xchm:")) + fwfn.GetFullPath(wxPATH_UNIX);
-	
-	return true;
-}
-
-
-wxHtmlOpeningStatus CHMHtmlWindow::OnOpeningURL(wxHtmlURLType type,
-						const wxString& url, 
-						wxString *redirect) const
-{
-	if(type == wxHTML_URL_PAGE)
-		return wxHTML_OPEN;
-
-	wxString tmp = url;
-
-	if(FixPath(tmp, _prefix)) {
-		*redirect = tmp;
-		return wxHTML_REDIRECT;
-	}
-
-	return wxHTML_OPEN;
-}
-
-
 void CHMHtmlWindow::OnLinkClicked(const wxHtmlLinkInfo& link)
 {
 	wxString url = link.GetHref();
@@ -369,6 +273,18 @@ void CHMHtmlWindow::OnBack(wxCommandEvent& WXUNUSED(event))
 }
 
 
+void CHMHtmlWindow::OnSize(wxSizeEvent& event)
+{
+	int x, y;
+	GetViewStart(&x, &y);
+
+	wxHtmlWindow::OnSize(event);
+
+	Scroll(x, y);
+	event.Skip(false);      
+}
+
+
 void CHMHtmlWindow::OnCopyLink(wxCommandEvent& WXUNUSED(event))
 {
 	if(wxTheClipboard->Open()) {
@@ -429,6 +345,7 @@ BEGIN_EVENT_TABLE(CHMHtmlWindow, wxHtmlWindow)
 	EVT_MENU(ID_CopyLink, CHMHtmlWindow::OnCopyLink)
 	EVT_CHAR(CHMHtmlWindow::OnChar)
 	EVT_RIGHT_DOWN(CHMHtmlWindow::OnRightClick)
+	EVT_SIZE(CHMHtmlWindow::OnSize)
 END_EVENT_TABLE()
 
 
