@@ -19,7 +19,7 @@
 */
 
 #include <chmsearchpanel.h>
-#include <contenttaghandler.h>
+#include <hhcparser.h>
 #include <chminputstream.h>
 #include <chmlistctrl.h>
 #include <chmhtmlwindow.h>
@@ -297,3 +297,17 @@ BEGIN_EVENT_TABLE(CHMSearchPanel, wxPanel)
 END_EVENT_TABLE()
 
 
+/*
+  Local Variables:
+  mode: c++
+  c-basic-offset: 8
+  tab-width: 8
+  c-indent-comments-syntactically-p: t
+  c-tab-always-indent: t
+  indent-tabs-mode: t
+  End:
+*/
+
+// vim:shiftwidth=8:autoindent:tabstop=8:noexpandtab:softtabstop=8
+
+
